/*
 * Copyright (C) 1997 by the University of Kansas Center for Research,
 * Inc.  This software was developed by the Information and
 * Telecommunication Technology Center (ITTC) at the University of
 * Kansas.  Partial funding for this project was provided by Sprint. This
 * software may be used and distributed according to the terms of the GNU
 * Public License, incorporated herein by reference.  Neither ITTC nor
 * Sprint accept any liability whatsoever for this product.
 *
 * This project was developed under the direction of Dr. Douglas Niehaus.
 *
 * Authors: Shyam Pather, Balaji Srinivasan 
 *
 * Please send bug-reports/suggestions/comments to posix@ittc.ukans.edu
 *
 * Further details about this project can be obtained at
 *    http://hegel.ittc.ukans.edu/projects/posix/
 */

/* clock_getrestest.c
 *
 * This program simply calls clock_getres().
 *
 * Author: Shyam Pather 
 */

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#ifdef __linux__
#include <posix_time.h>
#endif


int main() {
	struct timespec ts;
	int retval;
	
	retval = clock_getres(CLOCK_REALTIME, &ts);
	if (retval) {
	  perror("clock_getres() failed on CLOCK_REALTIME");
	  exit(1);
	}
	
	printf("(Resolution of CLOCK_REALTIME) tv_sec == %ld, tv_nsec == %ld\n", 
	       ts.tv_sec, ts.tv_nsec);		

	
	retval = clock_getres(33, &ts);
	if (retval) {
	  perror("clock_getres() failed on bogus clock value");
	}

#if 0
	retval = clock_getres(CLOCK_REALTIME, NULL);
	if (retval) {
	  perror("clock_getres() failed on CLOCK_REALTIME");
	}

	retval = clock_getres(CLOCK_REALTIME, (struct timespec*)1);
	if (retval) {
	  perror("clock_getres() failed on CLOCK_REALTIME");
	}
#endif
#if 1
	retval = clock_getres(CLOCK_LINUX_COUNTER, &ts);
	if (retval) {
	  perror("clock_getres() failed on CLOCK_LINUX_COUNTER");
	  exit(1);
	}
	
	printf("(Resolution of CLOCK_LINUX_COUNTER) tv_sec == %ld, tv_nsec == %ld\n", 
	       ts.tv_sec, ts.tv_nsec);		

#endif  
	return 0;
}
