/*
 * Copyright (C) 1997 by the University of Kansas Center for Research,
 * Inc.  This software was developed by the Information and
 * Telecommunication Technology Center (ITTC) at the University of
 * Kansas.  Partial funding for this project was provided by Sprint. This
 * software may be used and distributed according to the terms of the GNU
 * Public License, incorporated herein by reference.  Neither ITTC nor
 * Sprint accept any liability whatsoever for this product.
 *
 * This project was developed under the direction of Dr. Douglas Niehaus.
 *
 * Authors: Shyam Pather, Balaji Srinivasan 
 *
 * Please send bug-reports/suggestions/comments to posix@ittc.ukans.edu
 *
 * Further details about this project can be obtained at
 *    http://hegel.ittc.ukans.edu/projects/posix/
 */

/* clock_gettimetest2.c
 *
 * This program simply calls gettimeofday(), followed by clock_gettime() 
 * in a loop. The sequence of time values printed should be monotonically
 * increasing. The time values returned by clock_gettimeofday() have greater
 * accuracy than those returned by gettimeofday().
 */

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <sys/time.h>
#ifdef __linux__
#include <posix_time.h>
#endif


int main() {
	struct timespec ts;
	struct timeval tv;
	int i = 0, retval;

	for (;;i++) {
		retval = gettimeofday(&tv, NULL);
		if (retval) {
			perror("gettimeofday() failed");
			exit(1);
		}
		printf("(%d) tv_sec == %ld, tv_usec == %ld\n",i, 
		       tv.tv_sec, tv.tv_usec);
		
		retval = clock_gettime(CLOCK_REALTIME, &ts);
		if (retval) {
			perror("clock_gettime() failed");
			exit(1);
		}
		
		printf("(%d) tv_sec == %ld, tv_nsec == %ld\n",i, 
		       ts.tv_sec, ts.tv_nsec);		
	}
	return 0;
}
